==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_fields/GLFATTRIBUTES_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour GLFATTRIBUTES_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GLFATTRIBUTES_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="GLFATTRIBUTE1" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE2" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE3" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE4" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE5" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE6" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE7" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE8" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE9" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE10" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE11" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE12" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE13" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE14" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE15" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE16" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE17" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE18" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE19" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE20" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GLFATTRIBUTES_Type", propOrder = {
    "glfattribute1",
    "glfattribute2",
    "glfattribute3",
    "glfattribute4",
    "glfattribute5",
    "glfattribute6",
    "glfattribute7",
    "glfattribute8",
    "glfattribute9",
    "glfattribute10",
    "glfattribute11",
    "glfattribute12",
    "glfattribute13",
    "glfattribute14",
    "glfattribute15",
    "glfattribute16",
    "glfattribute17",
    "glfattribute18",
    "glfattribute19",
    "glfattribute20"
})
public class GLFATTRIBUTES_Type {

    @XmlElement(name = "GLFATTRIBUTE1", required = true)
    protected String glfattribute1;
    @XmlElement(name = "GLFATTRIBUTE2", required = true)
    protected String glfattribute2;
    @XmlElement(name = "GLFATTRIBUTE3", required = true)
    protected String glfattribute3;
    @XmlElement(name = "GLFATTRIBUTE4", required = true)
    protected String glfattribute4;
    @XmlElement(name = "GLFATTRIBUTE5", required = true)
    protected String glfattribute5;
    @XmlElement(name = "GLFATTRIBUTE6", required = true)
    protected String glfattribute6;
    @XmlElement(name = "GLFATTRIBUTE7", required = true)
    protected String glfattribute7;
    @XmlElement(name = "GLFATTRIBUTE8", required = true)
    protected String glfattribute8;
    @XmlElement(name = "GLFATTRIBUTE9", required = true)
    protected String glfattribute9;
    @XmlElement(name = "GLFATTRIBUTE10", required = true)
    protected String glfattribute10;
    @XmlElement(name = "GLFATTRIBUTE11", required = true)
    protected String glfattribute11;
    @XmlElement(name = "GLFATTRIBUTE12", required = true)
    protected String glfattribute12;
    @XmlElement(name = "GLFATTRIBUTE13", required = true)
    protected String glfattribute13;
    @XmlElement(name = "GLFATTRIBUTE14", required = true)
    protected String glfattribute14;
    @XmlElement(name = "GLFATTRIBUTE15", required = true)
    protected String glfattribute15;
    @XmlElement(name = "GLFATTRIBUTE16", required = true)
    protected String glfattribute16;
    @XmlElement(name = "GLFATTRIBUTE17", required = true)
    protected String glfattribute17;
    @XmlElement(name = "GLFATTRIBUTE18", required = true)
    protected String glfattribute18;
    @XmlElement(name = "GLFATTRIBUTE19", required = true)
    protected String glfattribute19;
    @XmlElement(name = "GLFATTRIBUTE20", required = true)
    protected String glfattribute20;

    /**
     * Obtient la valeur de la propriété glfattribute1.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE1() {
        return glfattribute1;
    }

    /**
     * Définit la valeur de la propriété glfattribute1.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE1(String value) {
        this.glfattribute1 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute2.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE2() {
        return glfattribute2;
    }

    /**
     * Définit la valeur de la propriété glfattribute2.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE2(String value) {
        this.glfattribute2 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute3.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE3() {
        return glfattribute3;
    }

    /**
     * Définit la valeur de la propriété glfattribute3.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE3(String value) {
        this.glfattribute3 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute4.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE4() {
        return glfattribute4;
    }

    /**
     * Définit la valeur de la propriété glfattribute4.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE4(String value) {
        this.glfattribute4 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute5.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE5() {
        return glfattribute5;
    }

    /**
     * Définit la valeur de la propriété glfattribute5.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE5(String value) {
        this.glfattribute5 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute6.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE6() {
        return glfattribute6;
    }

    /**
     * Définit la valeur de la propriété glfattribute6.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE6(String value) {
        this.glfattribute6 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute7.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE7() {
        return glfattribute7;
    }

    /**
     * Définit la valeur de la propriété glfattribute7.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE7(String value) {
        this.glfattribute7 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute8.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE8() {
        return glfattribute8;
    }

    /**
     * Définit la valeur de la propriété glfattribute8.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE8(String value) {
        this.glfattribute8 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute9.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE9() {
        return glfattribute9;
    }

    /**
     * Définit la valeur de la propriété glfattribute9.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE9(String value) {
        this.glfattribute9 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute10.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE10() {
        return glfattribute10;
    }

    /**
     * Définit la valeur de la propriété glfattribute10.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE10(String value) {
        this.glfattribute10 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute11.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE11() {
        return glfattribute11;
    }

    /**
     * Définit la valeur de la propriété glfattribute11.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE11(String value) {
        this.glfattribute11 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute12.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE12() {
        return glfattribute12;
    }

    /**
     * Définit la valeur de la propriété glfattribute12.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE12(String value) {
        this.glfattribute12 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute13.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE13() {
        return glfattribute13;
    }

    /**
     * Définit la valeur de la propriété glfattribute13.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE13(String value) {
        this.glfattribute13 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute14.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE14() {
        return glfattribute14;
    }

    /**
     * Définit la valeur de la propriété glfattribute14.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE14(String value) {
        this.glfattribute14 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute15.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE15() {
        return glfattribute15;
    }

    /**
     * Définit la valeur de la propriété glfattribute15.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE15(String value) {
        this.glfattribute15 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute16.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE16() {
        return glfattribute16;
    }

    /**
     * Définit la valeur de la propriété glfattribute16.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE16(String value) {
        this.glfattribute16 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute17.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE17() {
        return glfattribute17;
    }

    /**
     * Définit la valeur de la propriété glfattribute17.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE17(String value) {
        this.glfattribute17 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute18.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE18() {
        return glfattribute18;
    }

    /**
     * Définit la valeur de la propriété glfattribute18.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE18(String value) {
        this.glfattribute18 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute19.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE19() {
        return glfattribute19;
    }

    /**
     * Définit la valeur de la propriété glfattribute19.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE19(String value) {
        this.glfattribute19 = value;
    }

    /**
     * Obtient la valeur de la propriété glfattribute20.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE20() {
        return glfattribute20;
    }

    /**
     * Définit la valeur de la propriété glfattribute20.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE20(String value) {
        this.glfattribute20 = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/GLFATTRIBUTES_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GLFATTRIBUTES_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GLFATTRIBUTES_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="GLFATTRIBUTE1" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE2" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE3" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE4" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE5" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE6" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE7" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE8" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE9" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE10" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE11" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE12" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE13" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE14" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE15" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE16" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE17" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE18" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE19" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *         &lt;element name="GLFATTRIBUTE20" type="{http://schemas.datastream.net/MP_fields}CODE150_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GLFATTRIBUTES_Type", propOrder = {
    "glfattribute1",
    "glfattribute2",
    "glfattribute3",
    "glfattribute4",
    "glfattribute5",
    "glfattribute6",
    "glfattribute7",
    "glfattribute8",
    "glfattribute9",
    "glfattribute10",
    "glfattribute11",
    "glfattribute12",
    "glfattribute13",
    "glfattribute14",
    "glfattribute15",
    "glfattribute16",
    "glfattribute17",
    "glfattribute18",
    "glfattribute19",
    "glfattribute20"
})
public class GLFATTRIBUTES_Type {

    @XmlElement(name = "GLFATTRIBUTE1", required = true)
    protected String glfattribute1;
    @XmlElement(name = "GLFATTRIBUTE2", required = true)
    protected String glfattribute2;
    @XmlElement(name = "GLFATTRIBUTE3", required = true)
    protected String glfattribute3;
    @XmlElement(name = "GLFATTRIBUTE4", required = true)
    protected String glfattribute4;
    @XmlElement(name = "GLFATTRIBUTE5", required = true)
    protected String glfattribute5;
    @XmlElement(name = "GLFATTRIBUTE6", required = true)
    protected String glfattribute6;
    @XmlElement(name = "GLFATTRIBUTE7", required = true)
    protected String glfattribute7;
    @XmlElement(name = "GLFATTRIBUTE8", required = true)
    protected String glfattribute8;
    @XmlElement(name = "GLFATTRIBUTE9", required = true)
    protected String glfattribute9;
    @XmlElement(name = "GLFATTRIBUTE10", required = true)
    protected String glfattribute10;
    @XmlElement(name = "GLFATTRIBUTE11", required = true)
    protected String glfattribute11;
    @XmlElement(name = "GLFATTRIBUTE12", required = true)
    protected String glfattribute12;
    @XmlElement(name = "GLFATTRIBUTE13", required = true)
    protected String glfattribute13;
    @XmlElement(name = "GLFATTRIBUTE14", required = true)
    protected String glfattribute14;
    @XmlElement(name = "GLFATTRIBUTE15", required = true)
    protected String glfattribute15;
    @XmlElement(name = "GLFATTRIBUTE16", required = true)
    protected String glfattribute16;
    @XmlElement(name = "GLFATTRIBUTE17", required = true)
    protected String glfattribute17;
    @XmlElement(name = "GLFATTRIBUTE18", required = true)
    protected String glfattribute18;
    @XmlElement(name = "GLFATTRIBUTE19", required = true)
    protected String glfattribute19;
    @XmlElement(name = "GLFATTRIBUTE20", required = true)
    protected String glfattribute20;

    /**
     * Gets the value of the glfattribute1 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE1() {
        return glfattribute1;
    }

    /**
     * Sets the value of the glfattribute1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE1(String value) {
        this.glfattribute1 = value;
    }

    /**
     * Gets the value of the glfattribute2 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE2() {
        return glfattribute2;
    }

    /**
     * Sets the value of the glfattribute2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE2(String value) {
        this.glfattribute2 = value;
    }

    /**
     * Gets the value of the glfattribute3 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE3() {
        return glfattribute3;
    }

    /**
     * Sets the value of the glfattribute3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE3(String value) {
        this.glfattribute3 = value;
    }

    /**
     * Gets the value of the glfattribute4 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE4() {
        return glfattribute4;
    }

    /**
     * Sets the value of the glfattribute4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE4(String value) {
        this.glfattribute4 = value;
    }

    /**
     * Gets the value of the glfattribute5 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE5() {
        return glfattribute5;
    }

    /**
     * Sets the value of the glfattribute5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE5(String value) {
        this.glfattribute5 = value;
    }

    /**
     * Gets the value of the glfattribute6 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE6() {
        return glfattribute6;
    }

    /**
     * Sets the value of the glfattribute6 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE6(String value) {
        this.glfattribute6 = value;
    }

    /**
     * Gets the value of the glfattribute7 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE7() {
        return glfattribute7;
    }

    /**
     * Sets the value of the glfattribute7 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE7(String value) {
        this.glfattribute7 = value;
    }

    /**
     * Gets the value of the glfattribute8 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE8() {
        return glfattribute8;
    }

    /**
     * Sets the value of the glfattribute8 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE8(String value) {
        this.glfattribute8 = value;
    }

    /**
     * Gets the value of the glfattribute9 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE9() {
        return glfattribute9;
    }

    /**
     * Sets the value of the glfattribute9 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE9(String value) {
        this.glfattribute9 = value;
    }

    /**
     * Gets the value of the glfattribute10 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE10() {
        return glfattribute10;
    }

    /**
     * Sets the value of the glfattribute10 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE10(String value) {
        this.glfattribute10 = value;
    }

    /**
     * Gets the value of the glfattribute11 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE11() {
        return glfattribute11;
    }

    /**
     * Sets the value of the glfattribute11 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE11(String value) {
        this.glfattribute11 = value;
    }

    /**
     * Gets the value of the glfattribute12 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE12() {
        return glfattribute12;
    }

    /**
     * Sets the value of the glfattribute12 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE12(String value) {
        this.glfattribute12 = value;
    }

    /**
     * Gets the value of the glfattribute13 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE13() {
        return glfattribute13;
    }

    /**
     * Sets the value of the glfattribute13 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE13(String value) {
        this.glfattribute13 = value;
    }

    /**
     * Gets the value of the glfattribute14 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE14() {
        return glfattribute14;
    }

    /**
     * Sets the value of the glfattribute14 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE14(String value) {
        this.glfattribute14 = value;
    }

    /**
     * Gets the value of the glfattribute15 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE15() {
        return glfattribute15;
    }

    /**
     * Sets the value of the glfattribute15 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE15(String value) {
        this.glfattribute15 = value;
    }

    /**
     * Gets the value of the glfattribute16 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE16() {
        return glfattribute16;
    }

    /**
     * Sets the value of the glfattribute16 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE16(String value) {
        this.glfattribute16 = value;
    }

    /**
     * Gets the value of the glfattribute17 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE17() {
        return glfattribute17;
    }

    /**
     * Sets the value of the glfattribute17 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE17(String value) {
        this.glfattribute17 = value;
    }

    /**
     * Gets the value of the glfattribute18 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE18() {
        return glfattribute18;
    }

    /**
     * Sets the value of the glfattribute18 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE18(String value) {
        this.glfattribute18 = value;
    }

    /**
     * Gets the value of the glfattribute19 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE19() {
        return glfattribute19;
    }

    /**
     * Sets the value of the glfattribute19 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE19(String value) {
        this.glfattribute19 = value;
    }

    /**
     * Gets the value of the glfattribute20 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLFATTRIBUTE20() {
        return glfattribute20;
    }

    /**
     * Sets the value of the glfattribute20 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLFATTRIBUTE20(String value) {
        this.glfattribute20 = value;
    }

}
